@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """Astroid hooks for the Python 2 GObject introspection bindings.
 
@@ -54,11 +54,42 @@ _special_methods = frozenset(
 )
 
 
+def _gi_supports_inspect_signature():
+    """
+    Indicates if pygobject supports inspect.signature().
+    """
+    import gi
+
+    try:
+        # inspect.signature() is supported since pygobject==3.51.0 (ee9558e4).
+        gi.check_version((3, 51, 0))
+        return True
+    except ValueError:
+        pass
+    return False
+
+
+def _gi_is_method_call(obj):
+    if _gi_supports_inspect_signature():
+        # Since inspect.signature() is supported, the workaround to use
+        # inspect.ismethoddescriptor() was disabled and cannot be used anymore
+        # to tell apart functions from methods.
+        # See https://github.com/pylint-dev/astroid/issues/2594
+        try:
+            sig = str(inspect.signature(obj))
+            return sig == "(self)" or sig.startswith("(self, ")
+        except Exception:  # pylint: disable=broad-except
+            return False
+    return inspect.ismethod(obj) or inspect.ismethoddescriptor(obj)
+
+
 def _gi_build_stub(parent):  # noqa: C901
     """
     Inspect the passed module recursively and build stubs for functions,
     classes, etc.
     """
+    # pylint: disable = too-many-branches, too-many-statements
+
     classes = {}
     functions = {}
     constants = {}
@@ -82,7 +113,7 @@ def _gi_build_stub(parent):  # noqa: C901
             classes[name] = obj
         elif inspect.isfunction(obj) or inspect.isbuiltin(obj):
             functions[name] = obj
-        elif inspect.ismethod(obj) or inspect.ismethoddescriptor(obj):
+        elif _gi_is_method_call(obj):
             methods[name] = obj
         elif (
             str(obj).startswith("<flags")
@@ -243,7 +274,8 @@ def _register_require_version(node):
     return node
 
 
-AstroidManager().register_failed_import_hook(_import_gi_module)
-AstroidManager().register_transform(
-    nodes.Call, _register_require_version, _looks_like_require_version
-)
+def register(manager: AstroidManager) -> None:
+    manager.register_failed_import_hook(_import_gi_module)
+    manager.register_transform(
+        nodes.Call, _register_require_version, _looks_like_require_version
+    )
