@@ -13,7 +13,7 @@ import pytest
 
 import astroid
 from astroid import extract_node, nodes
-from astroid.const import PY310_PLUS, PY312_PLUS
+from astroid.const import PY312_PLUS
 from astroid.exceptions import InferenceError
 from astroid.manager import AstroidManager
 from astroid.util import Uninferable, UninferableBase
@@ -53,15 +53,13 @@ class ProtocolTests(unittest.TestCase):
             self.assertEqual(expected_name, node.name)
 
     def test_assigned_stmts_simple_for(self) -> None:
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         for a in (1, 2, 3):  #@
           pass
 
         for b in range(3): #@
           pass
-        """
-        )
+        """)
 
         for1_assnode = next(assign_stmts[0].nodes_of_class(nodes.AssignName))
         assigned = list(for1_assnode.assigned_stmts())
@@ -71,12 +69,10 @@ class ProtocolTests(unittest.TestCase):
         self.assertRaises(InferenceError, list, for2_assnode.assigned_stmts())
 
     def test_assigned_stmts_nested_for_tuple(self) -> None:
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         for a, (b, c) in [(1, (2, 3))]:  #@
           pass
-        """
-        )
+        """)
 
         assign_nodes = assign_stmts.nodes_of_class(nodes.AssignName)
 
@@ -89,12 +85,10 @@ class ProtocolTests(unittest.TestCase):
         self.assertConstNodesEqual([2], assigned2)
 
     def test_assigned_stmts_nested_for_dict(self) -> None:
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         for a, (b, c) in {1: ("a", str), 2: ("b", bytes)}.items():  #@
             pass
-        """
-        )
+        """)
         assign_nodes = assign_stmts.nodes_of_class(nodes.AssignName)
 
         # assigned: [1, 2]
@@ -113,16 +107,14 @@ class ProtocolTests(unittest.TestCase):
         self.assertNameNodesEqual(["str", "bytes"], assigned3)
 
     def test_assigned_stmts_starred_for(self) -> None:
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         for *a, b in ((1, 2, 3), (4, 5, 6, 7)): #@
             pass
-        """
-        )
+        """)
 
         for1_starred = next(assign_stmts.nodes_of_class(nodes.Starred))
         assigned = next(for1_starred.assigned_stmts())
-        assert isinstance(assigned, astroid.List)
+        assert isinstance(assigned, nodes.List)
         assert assigned.as_string() == "[1, 2]"
 
     def _get_starred_stmts(self, code: str) -> list | UninferableBase:
@@ -191,13 +183,11 @@ class ProtocolTests(unittest.TestCase):
         )
 
     def test_assigned_stmts_assignments(self) -> None:
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         c = a #@
 
         d, e = b, c #@
-        """
-        )
+        """)
 
         simple_assnode = next(assign_stmts[0].nodes_of_class(nodes.AssignName))
         assigned = list(simple_assnode.assigned_stmts())
@@ -212,12 +202,10 @@ class ProtocolTests(unittest.TestCase):
         self.assertNameNodesEqual(["c"], assigned)
 
     def test_assigned_stmts_annassignments(self) -> None:
-        annassign_stmts = extract_node(
-            """
+        annassign_stmts = extract_node("""
         a: str = "abc"  #@
         b: str  #@
-        """
-        )
+        """)
         simple_annassign_node = next(
             annassign_stmts[0].nodes_of_class(nodes.AssignName)
         )
@@ -236,12 +224,10 @@ class ProtocolTests(unittest.TestCase):
             node.root().locals["__all__"] = [node.value]
 
         manager = astroid.MANAGER
-        with _add_transform(manager, astroid.Assign, transform):
-            module = astroid.parse(
-                """
+        with _add_transform(manager, nodes.Assign, transform):
+            module = astroid.parse("""
             __all__ = ['a']
-            """
-            )
+            """)
             module.wildcard_import_names()
 
     def test_not_passing_uninferable_in_seq_inference(self) -> None:
@@ -261,12 +247,10 @@ class ProtocolTests(unittest.TestCase):
                 for _ in node.infer():
                     pass
 
-        parsed = extract_node(
-            """
+        parsed = extract_node("""
         a = []
         x = [a*2, a]*2*2
-        """
-        )
+        """)
         parsed.accept(Visitor())
 
     @staticmethod
@@ -286,6 +270,28 @@ class ProtocolTests(unittest.TestCase):
         element = parsed.inferred()[0].elts[0]
         assert element.value is Uninferable
 
+    @staticmethod
+    def test_uninferable_list_multiplication_with_multiple_operands() -> None:
+        """Attempting to calculate the result is prohibitively expensive."""
+        parsed = extract_node("[0] * 825 * 16547118")
+        element = parsed.inferred()[0].elts[0]
+        assert element.value is Uninferable
+
+    @staticmethod
+    def test_list_multiplication_with_empty_list_and_overflowing_multiplier() -> None:
+        parsed = extract_node("[] * 1163845194457646539560")
+        assert parsed.inferred()[0].elts == []
+
+    @staticmethod
+    def test_list_multiplication_with_zero_multiplier() -> None:
+        parsed = extract_node("[0] * 0")
+        assert parsed.inferred()[0].elts == []
+
+    @staticmethod
+    def test_list_multiplication_with_negative_overflowing_multiplier() -> None:
+        parsed = extract_node("[0] * -9223372036854775809")
+        assert parsed.inferred()[0].elts == []
+
 
 def test_named_expr_inference() -> None:
     code = """
@@ -342,7 +348,6 @@ def test_named_expr_inference() -> None:
     assert node.value == 1
 
 
-@pytest.mark.skipif(not PY310_PLUS, reason="Match requires python 3.10")
 class TestPatternMatching:
     @staticmethod
     def test_assigned_stmts_match_mapping():
@@ -350,14 +355,12 @@ class TestPatternMatching:
 
         Test the result is 'Uninferable' and no exception is raised.
         """
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         var = {1: "Hello", 2: "World"}
         match var:
             case {**rest}:  #@
                 pass
-        """
-        )
+        """)
         match_mapping: nodes.MatchMapping = assign_stmts.pattern  # type: ignore[union-attr]
         assert match_mapping.rest
         assigned = next(match_mapping.rest.assigned_stmts())
@@ -369,14 +372,12 @@ class TestPatternMatching:
 
         Test the result is 'Uninferable' and no exception is raised.
         """
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         var = (0, 1, 2)
         match var:
             case (0, 1, *rest):  #@
                 pass
-        """
-        )
+        """)
         match_sequence: nodes.MatchSequence = assign_stmts.pattern  # type: ignore[union-attr]
         match_star = match_sequence.patterns[2]
         assert isinstance(match_star, nodes.MatchStar) and match_star.name
@@ -386,8 +387,7 @@ class TestPatternMatching:
     @staticmethod
     def test_assigned_stmts_match_as():
         """Assigned_stmts for MatchAs only implemented for the most basic case (y)."""
-        assign_stmts = extract_node(
-            """
+        assign_stmts = extract_node("""
         var = 42
         match var:  #@
             case 2 | x:  #@
@@ -396,8 +396,7 @@ class TestPatternMatching:
                 pass
             case z:  #@
                 pass
-        """
-        )
+        """)
         subject: nodes.Const = assign_stmts[0].subject  # type: ignore[index,union-attr]
         match_or: nodes.MatchOr = assign_stmts[1].pattern  # type: ignore[index,union-attr]
         match_as_with_pattern: nodes.MatchAs = assign_stmts[2].pattern  # type: ignore[index,union-attr]
